@@ -3,8 +3,10 @@ from .classes import (
     AgentRequest,
     Document,
     DocumentRequest,
+    Element,
     ExtractedField,
     GroundXDocument,
+    Group,
     ProcessResponse,
     Prompt,
     TestChunk,
@@ -30,9 +32,11 @@ __all__ = [
     "ContainerUploadSettings",
     "Document",
     "DocumentRequest",
+    "Element",
     "ExtractedField",
     "GroundXDocument",
     "GroundXSettings",
+    "Group",
     "Logger",
     "ProcessResponse",
     "Prompt",
