@@ -1,19 +1,24 @@
 from .agent import AgentRequest
 from .api import ProcessResponse
 from .document import Document, DocumentRequest
+from .element import Element
 from .field import ExtractedField
 from .groundx import GroundXDocument, XRayDocument
+from .group import Group
 from .prompt import Prompt
 from .test_field import TestField
 from .test_groundx import TestChunk, TestDocumentPage, TestXRay
+from .utility import from_attr_name, from_key
 
 
 __all__ = [
     "AgentRequest",
     "Document",
     "DocumentRequest",
+    "Element",
     "ExtractedField",
     "GroundXDocument",
+    "Group",
     "ProcessResponse",
     "Prompt",
     "TestChunk",
@@ -21,4 +26,6 @@ __all__ = [
     "TestField",
     "TestXRay",
     "XRayDocument",
+    "from_attr_name",
+    "from_key",
 ]
