@@ -7,15 +7,16 @@ from pydantic import BaseModel, ConfigDict, Field, PrivateAttr
 from urllib.parse import urlparse
 
 from .groundx import GroundXDocument
+from .group import Group
 from ..services.logger import Logger
 from ..services.upload import Upload
-from ..utility.classes import clean_json
+from ..utility import clean_json
 
 
 DocT = typing.TypeVar("DocT", bound="Document")
 
 
-class Document(BaseModel):
+class Document(Group):
     file_name: str = ""
 
     document_id: str = ""
@@ -137,6 +138,7 @@ class DocumentRequest(BaseModel):
     model_id: int = Field(alias="modelID")
     processor_id: int = Field(alias="processorID")
     task_id: str = Field(alias="taskID")
+    workflow_id: typing.Optional[str] = Field(alias="workflowID", default="latest")
 
     _logger: typing.Optional[Logger] = PrivateAttr(default=None)
 
