@@ -3,6 +3,8 @@ from pathlib import Path
 
 from pydantic import BaseModel, ConfigDict, Field
 
+from ..services.upload import Upload
+
 
 class GroundXDocument(BaseModel):
     model_config = ConfigDict(populate_by_name=True)
@@ -10,6 +12,9 @@ class GroundXDocument(BaseModel):
     document_id: str = Field(alias="documentID")
     task_id: str = Field(alias="taskID")
 
+    def xray_path(self) -> str:
+        return f"layout/processed/{self.task_id}/{self.document_id}-xray.json"
+
     def xray_url(self, base: typing.Optional[str] = None) -> str:
         if not base:
             base = self.base_url
@@ -20,6 +25,7 @@ class GroundXDocument(BaseModel):
     def xray(
         self,
         cache_dir: Path,
+        upload: typing.Optional[Upload] = None,
         clear_cache: bool = False,
         is_test: bool = False,
         base: typing.Optional[str] = None,
@@ -27,9 +33,10 @@ class GroundXDocument(BaseModel):
         return XRayDocument.download(
             self,
             cache_dir=cache_dir,
-            base=base,
+            upload=upload,
             clear_cache=clear_cache,
             is_test=is_test,
+            base=base,
         )
 
 
@@ -87,6 +94,7 @@ class XRayDocument(BaseModel):
         cls,
         gx_doc: GroundXDocument,
         cache_dir: Path,
+        upload: typing.Optional[Upload] = None,
         clear_cache: bool = False,
         is_test: bool = False,
         base: typing.Optional[str] = None,
@@ -99,30 +107,41 @@ class XRayDocument(BaseModel):
                 with cache_file.open("r", encoding="utf-8") as f:
                     payload = json.load(f)
 
+                return cls(**payload)
             except Exception as e:
                 raise RuntimeError(
                     f"Error loading cached X-ray JSON from {cache_file}: {e}"
                 )
-        else:
-            url = gx_doc.xray_url(base=base)
-            try:
-                resp = requests.get(url)
-                resp.raise_for_status()
-            except requests.RequestException as e:
-                raise RuntimeError(f"Error fetching X-ray JSON from {url}: {e}")
 
-            try:
-                payload = resp.json()
-            except ValueError as e:
-                raise RuntimeError(f"Invalid JSON returned from {url}: {e}")
-
-            if is_test is False:
+        if upload:
+            path = gx_doc.xray_path()
+            ru = upload.get_object(path)
+            if ru:
                 try:
-                    with cache_file.open("w", encoding="utf-8") as f:
-                        json.dump(payload, f)
+                    payload = json.loads(ru.decode("utf-8"))
+                    return cls(**payload)
                 except Exception as e:
-                    print(
-                        f"Warning: failed to write X-ray JSON cache to {cache_file}: {e}"
+                    raise RuntimeError(
+                        f"Error decoding X-ray JSON bytes from {path}: {e}"
                     )
 
+        url = gx_doc.xray_url(base=base)
+        try:
+            resp = requests.get(url)
+            resp.raise_for_status()
+        except requests.RequestException as e:
+            raise RuntimeError(f"Error fetching X-ray JSON from {url}: {e}")
+
+        try:
+            payload = resp.json()
+        except ValueError as e:
+            raise RuntimeError(f"Invalid JSON returned from {url}: {e}")
+
+        if is_test is False:
+            try:
+                with cache_file.open("w", encoding="utf-8") as f:
+                    json.dump(payload, f)
+            except Exception as e:
+                print(f"Warning: failed to write X-ray JSON cache to {cache_file}: {e}")
+
         return cls(**payload)
